##########
adobefonts
##########

All vendor-specific profiles such as the `adobefonts` one also include the checks from the :doc:`universal` profile.

.. automodule:: fontbakery.profiles.adobefonts
   :members:
   :undoc-members:
